@@ -5,7 +5,7 @@
 #' @param probs A data frame consisting of one play that has had `add_4th_probs()` already run on it.
 #' @return A table showing the probabilities associated with each possible choice.
 #' @export
-#' @examples
+#' @examplesIf identical(data.table::getDTthreads(FALSE), 2L) || identical(Sys.getenv("IN_PKGDOWN"), "true")
 #' \donttest{
 #' play <-
 #'   tibble::tibble(
@@ -32,14 +32,13 @@
 #' nfl4th::make_table_data(probs)
 #'}
 make_table_data <- function(probs) {
-
   go <- tibble::tibble(
     "choice_prob" = probs$go_wp,
     "choice" = "Go for it",
     "success_prob" = probs$first_down_prob,
     "fail_wp" = probs$wp_fail,
     "success_wp" = probs$wp_succeed
-  ) %>%
+  ) |>
     select(choice, choice_prob, success_prob, fail_wp, success_wp)
 
   fg <- tibble::tibble(
@@ -48,7 +47,7 @@ make_table_data <- function(probs) {
     "success_prob" = probs$fg_make_prob,
     "fail_wp" = probs$miss_fg_wp,
     "success_wp" = probs$make_fg_wp
-  ) %>%
+  ) |>
     select(choice, choice_prob, success_prob, fail_wp, success_wp)
 
   punt <- tibble::tibble(
@@ -57,12 +56,14 @@ make_table_data <- function(probs) {
     "success_prob" = NA_real_,
     "fail_wp" = NA_real_,
     "success_wp" = NA_real_
-  ) %>%
+  ) |>
     select(choice, choice_prob, success_prob, fail_wp, success_wp)
 
   for_return <- bind_rows(
-    go, fg, punt
-  ) %>%
+    go,
+    fg,
+    punt
+  ) |>
     mutate(
       choice_prob = 100 * choice_prob,
       success_prob = 100 * success_prob,
@@ -81,7 +82,7 @@ make_table_data <- function(probs) {
 #' @param probs A data frame consisting of one play that has had `add_2pt_probs()` already run on it.
 #' @return A table showing the probabilities associated with each possible choice.
 #' @export
-#' @examples
+#' @examplesIf identical(data.table::getDTthreads(FALSE), 2L) || identical(Sys.getenv("IN_PKGDOWN"), "true")
 #' \donttest{
 #' play <-
 #'   tibble::tibble(
@@ -106,14 +107,13 @@ make_table_data <- function(probs) {
 #' nfl4th::make_2pt_table_data(probs)
 #' }
 make_2pt_table_data <- function(probs) {
-
   go <- tibble::tibble(
     "choice_prob" = probs$wp_go2,
     "choice" = "Go for 2",
     "success_prob" = probs$conv_2pt,
     "fail_wp" = probs$wp_0,
     "success_wp" = probs$wp_2
-  ) %>%
+  ) |>
     select(choice, choice_prob, success_prob, fail_wp, success_wp)
 
   pat <- tibble::tibble(
@@ -122,12 +122,13 @@ make_2pt_table_data <- function(probs) {
     "success_prob" = probs$conv_1pt,
     "fail_wp" = probs$wp_0,
     "success_wp" = probs$wp_1
-  ) %>%
+  ) |>
     select(choice, choice_prob, success_prob, fail_wp, success_wp)
 
   for_return <- bind_rows(
-    go, pat
-  ) %>%
+    go,
+    pat
+  ) |>
     mutate(
       choice_prob = 100 * choice_prob,
       success_prob = 100 * success_prob,
